# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/job.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import postal_address_pb2 as google_dot_type_dot_postal__address__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/job.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\020JobResourceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        "\n+google/cloud/talent_v4beta1/proto/job.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a google/type/postal_address.proto\x1a\x1cgoogle/api/annotations.proto\"\xe0\x0f\n\x03Job\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x07\x63ompany\x18\x02 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bjobs.googleapis.com/Company\x12\x1b\n\x0erequisition_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05title\x18\x04 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\taddresses\x18\x06 \x03(\t\x12J\n\x10\x61pplication_info\x18\x07 \x01(\x0b\x32\x30.google.cloud.talent.v4beta1.Job.ApplicationInfo\x12=\n\x0cjob_benefits\x18\x08 \x03(\x0e\x32'.google.cloud.talent.v4beta1.JobBenefit\x12H\n\x11\x63ompensation_info\x18\t \x01(\x0b\x32-.google.cloud.talent.v4beta1.CompensationInfo\x12Q\n\x11\x63ustom_attributes\x18\n \x03(\x0b\x32\x36.google.cloud.talent.v4beta1.Job.CustomAttributesEntry\x12=\n\x0c\x64\x65gree_types\x18\x0b \x03(\x0e\x32'.google.cloud.talent.v4beta1.DegreeType\x12\x12\n\ndepartment\x18\x0c \x01(\t\x12\x45\n\x10\x65mployment_types\x18\r \x03(\x0e\x32+.google.cloud.talent.v4beta1.EmploymentType\x12\x12\n\nincentives\x18\x0e \x01(\t\x12\x15\n\rlanguage_code\x18\x0f \x01(\t\x12\x38\n\tjob_level\x18\x10 \x01(\x0e\x32%.google.cloud.talent.v4beta1.JobLevel\x12\x17\n\x0fpromotion_value\x18\x11 \x01(\x05\x12\x16\n\x0equalifications\x18\x12 \x01(\t\x12\x18\n\x10responsibilities\x18\x13 \x01(\t\x12\x42\n\x0eposting_region\x18\x14 \x01(\x0e\x32*.google.cloud.talent.v4beta1.PostingRegion\x12?\n\nvisibility\x18\x15 \x01(\x0e\x32'.google.cloud.talent.v4beta1.VisibilityB\x02\x18\x01\x12\x32\n\x0ejob_start_time\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cjob_end_time\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14posting_publish_time\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13posting_expire_time\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x13posting_create_time\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12<\n\x13posting_update_time\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12!\n\x14\x63ompany_display_name\x18\x1c \x01(\tB\x03\xe0\x41\x03\x12G\n\x0c\x64\x65rived_info\x18\x1d \x01(\x0b\x32,.google.cloud.talent.v4beta1.Job.DerivedInfoB\x03\xe0\x41\x03\x12N\n\x12processing_options\x18\x1e \x01(\x0b\x32\x32.google.cloud.talent.v4beta1.Job.ProcessingOptions\x1a\x44\n\x0f\x41pplicationInfo\x12\x0e\n\x06\x65mails\x18\x01 \x03(\t\x12\x13\n\x0binstruction\x18\x02 \x01(\t\x12\x0c\n\x04uris\x18\x03 \x03(\t\x1a\x89\x01\n\x0b\x44\x65rivedInfo\x12\x38\n\tlocations\x18\x01 \x03(\x0b\x32%.google.cloud.talent.v4beta1.Location\x12@\n\x0ejob_categories\x18\x03 \x03(\x0e\x32(.google.cloud.talent.v4beta1.JobCategory\x1a\x88\x01\n\x11ProcessingOptions\x12)\n!disable_street_address_resolution\x18\x01 \x01(\x08\x12H\n\x11html_sanitization\x18\x02 \x01(\x0e\x32-.google.cloud.talent.v4beta1.HtmlSanitization\x1a\x65\n\x15\x43ustomAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.google.cloud.talent.v4beta1.CustomAttribute:\x02\x38\x01:k\xea\x41h\n\x17jobs.googleapis.com/Job\x12\x1dprojects/{project}/jobs/{job}\x12.projects/{project}/tenants/{tenant}/jobs/{job}B~\n\x1f\x63om.google.cloud.talent.v4beta1B\x10JobResourceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3"
    ),
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_type_dot_postal__address__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_JOB_APPLICATIONINFO = _descriptor.Descriptor(
    name="ApplicationInfo",
    full_name="google.cloud.talent.v4beta1.Job.ApplicationInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="emails",
            full_name="google.cloud.talent.v4beta1.Job.ApplicationInfo.emails",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="instruction",
            full_name="google.cloud.talent.v4beta1.Job.ApplicationInfo.instruction",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="uris",
            full_name="google.cloud.talent.v4beta1.Job.ApplicationInfo.uris",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1739,
    serialized_end=1807,
)

_JOB_DERIVEDINFO = _descriptor.Descriptor(
    name="DerivedInfo",
    full_name="google.cloud.talent.v4beta1.Job.DerivedInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="locations",
            full_name="google.cloud.talent.v4beta1.Job.DerivedInfo.locations",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_categories",
            full_name="google.cloud.talent.v4beta1.Job.DerivedInfo.job_categories",
            index=1,
            number=3,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1810,
    serialized_end=1947,
)

_JOB_PROCESSINGOPTIONS = _descriptor.Descriptor(
    name="ProcessingOptions",
    full_name="google.cloud.talent.v4beta1.Job.ProcessingOptions",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="disable_street_address_resolution",
            full_name="google.cloud.talent.v4beta1.Job.ProcessingOptions.disable_street_address_resolution",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="html_sanitization",
            full_name="google.cloud.talent.v4beta1.Job.ProcessingOptions.html_sanitization",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1950,
    serialized_end=2086,
)

_JOB_CUSTOMATTRIBUTESENTRY = _descriptor.Descriptor(
    name="CustomAttributesEntry",
    full_name="google.cloud.talent.v4beta1.Job.CustomAttributesEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.talent.v4beta1.Job.CustomAttributesEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.talent.v4beta1.Job.CustomAttributesEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2088,
    serialized_end=2189,
)

_JOB = _descriptor.Descriptor(
    name="Job",
    full_name="google.cloud.talent.v4beta1.Job",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.Job.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="company",
            full_name="google.cloud.talent.v4beta1.Job.company",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A\035\n\033jobs.googleapis.com/Company"
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="requisition_id",
            full_name="google.cloud.talent.v4beta1.Job.requisition_id",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="title",
            full_name="google.cloud.talent.v4beta1.Job.title",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.talent.v4beta1.Job.description",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="addresses",
            full_name="google.cloud.talent.v4beta1.Job.addresses",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="application_info",
            full_name="google.cloud.talent.v4beta1.Job.application_info",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_benefits",
            full_name="google.cloud.talent.v4beta1.Job.job_benefits",
            index=7,
            number=8,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="compensation_info",
            full_name="google.cloud.talent.v4beta1.Job.compensation_info",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="custom_attributes",
            full_name="google.cloud.talent.v4beta1.Job.custom_attributes",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="degree_types",
            full_name="google.cloud.talent.v4beta1.Job.degree_types",
            index=10,
            number=11,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="department",
            full_name="google.cloud.talent.v4beta1.Job.department",
            index=11,
            number=12,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="employment_types",
            full_name="google.cloud.talent.v4beta1.Job.employment_types",
            index=12,
            number=13,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="incentives",
            full_name="google.cloud.talent.v4beta1.Job.incentives",
            index=13,
            number=14,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.talent.v4beta1.Job.language_code",
            index=14,
            number=15,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_level",
            full_name="google.cloud.talent.v4beta1.Job.job_level",
            index=15,
            number=16,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="promotion_value",
            full_name="google.cloud.talent.v4beta1.Job.promotion_value",
            index=16,
            number=17,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="qualifications",
            full_name="google.cloud.talent.v4beta1.Job.qualifications",
            index=17,
            number=18,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="responsibilities",
            full_name="google.cloud.talent.v4beta1.Job.responsibilities",
            index=18,
            number=19,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="posting_region",
            full_name="google.cloud.talent.v4beta1.Job.posting_region",
            index=19,
            number=20,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="visibility",
            full_name="google.cloud.talent.v4beta1.Job.visibility",
            index=20,
            number=21,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\030\001"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_start_time",
            full_name="google.cloud.talent.v4beta1.Job.job_start_time",
            index=21,
            number=22,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_end_time",
            full_name="google.cloud.talent.v4beta1.Job.job_end_time",
            index=22,
            number=23,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="posting_publish_time",
            full_name="google.cloud.talent.v4beta1.Job.posting_publish_time",
            index=23,
            number=24,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="posting_expire_time",
            full_name="google.cloud.talent.v4beta1.Job.posting_expire_time",
            index=24,
            number=25,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="posting_create_time",
            full_name="google.cloud.talent.v4beta1.Job.posting_create_time",
            index=25,
            number=26,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="posting_update_time",
            full_name="google.cloud.talent.v4beta1.Job.posting_update_time",
            index=26,
            number=27,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="company_display_name",
            full_name="google.cloud.talent.v4beta1.Job.company_display_name",
            index=27,
            number=28,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="derived_info",
            full_name="google.cloud.talent.v4beta1.Job.derived_info",
            index=28,
            number=29,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="processing_options",
            full_name="google.cloud.talent.v4beta1.Job.processing_options",
            index=29,
            number=30,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[
        _JOB_APPLICATIONINFO,
        _JOB_DERIVEDINFO,
        _JOB_PROCESSINGOPTIONS,
        _JOB_CUSTOMATTRIBUTESENTRY,
    ],
    enum_types=[],
    serialized_options=_b(
        "\352Ah\n\027jobs.googleapis.com/Job\022\035projects/{project}/jobs/{job}\022.projects/{project}/tenants/{tenant}/jobs/{job}"
    ),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=282,
    serialized_end=2298,
)

_JOB_APPLICATIONINFO.containing_type = _JOB
_JOB_DERIVEDINFO.fields_by_name[
    "locations"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._LOCATION
)
_JOB_DERIVEDINFO.fields_by_name[
    "job_categories"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._JOBCATEGORY
)
_JOB_DERIVEDINFO.containing_type = _JOB
_JOB_PROCESSINGOPTIONS.fields_by_name[
    "html_sanitization"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._HTMLSANITIZATION
)
_JOB_PROCESSINGOPTIONS.containing_type = _JOB
_JOB_CUSTOMATTRIBUTESENTRY.fields_by_name[
    "value"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._CUSTOMATTRIBUTE
)
_JOB_CUSTOMATTRIBUTESENTRY.containing_type = _JOB
_JOB.fields_by_name["application_info"].message_type = _JOB_APPLICATIONINFO
_JOB.fields_by_name[
    "job_benefits"
].enum_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._JOBBENEFIT
_JOB.fields_by_name[
    "compensation_info"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._COMPENSATIONINFO
)
_JOB.fields_by_name["custom_attributes"].message_type = _JOB_CUSTOMATTRIBUTESENTRY
_JOB.fields_by_name[
    "degree_types"
].enum_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._DEGREETYPE
_JOB.fields_by_name[
    "employment_types"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._EMPLOYMENTTYPE
)
_JOB.fields_by_name[
    "job_level"
].enum_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._JOBLEVEL
_JOB.fields_by_name[
    "posting_region"
].enum_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._POSTINGREGION
)
_JOB.fields_by_name[
    "visibility"
].enum_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._VISIBILITY
_JOB.fields_by_name[
    "job_start_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name[
    "job_end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name[
    "posting_publish_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name[
    "posting_expire_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name[
    "posting_create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name[
    "posting_update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name["derived_info"].message_type = _JOB_DERIVEDINFO
_JOB.fields_by_name["processing_options"].message_type = _JOB_PROCESSINGOPTIONS
DESCRIPTOR.message_types_by_name["Job"] = _JOB
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Job = _reflection.GeneratedProtocolMessageType(
    "Job",
    (_message.Message,),
    dict(
        ApplicationInfo=_reflection.GeneratedProtocolMessageType(
            "ApplicationInfo",
            (_message.Message,),
            dict(
                DESCRIPTOR=_JOB_APPLICATIONINFO,
                __module__="google.cloud.talent_v4beta1.proto.job_pb2",
                __doc__="""Application related details of a job posting.
    
    
    Attributes:
        emails:
            Use this field to specify email address(es) to which resumes
            or applications can be sent.  The maximum number of allowed
            characters for each entry is 255.
        instruction:
            Use this field to provide instructions, such as "Mail your
            application to ...", that a candidate can follow to apply for
            the job.  This field accepts and sanitizes HTML input, and
            also accepts bold, italic, ordered list, and unordered list
            markup tags.  The maximum number of allowed characters is
            3,000.
        uris:
            Use this URI field to direct an applicant to a website, for
            example to link to an online application form.  The maximum
            number of allowed characters for each entry is 2,000.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Job.ApplicationInfo)
            ),
        ),
        DerivedInfo=_reflection.GeneratedProtocolMessageType(
            "DerivedInfo",
            (_message.Message,),
            dict(
                DESCRIPTOR=_JOB_DERIVEDINFO,
                __module__="google.cloud.talent_v4beta1.proto.job_pb2",
                __doc__="""Derived details about the job posting.
    
    
    Attributes:
        locations:
            Structured locations of the job, resolved from
            [Job.addresses][google.cloud.talent.v4beta1.Job.addresses].  [
            locations][google.cloud.talent.v4beta1.Job.DerivedInfo.locatio
            ns] are exactly matched to
            [Job.addresses][google.cloud.talent.v4beta1.Job.addresses] in
            the same order.
        job_categories:
            Job categories derived from
            [Job.title][google.cloud.talent.v4beta1.Job.title] and [Job.de
            scription][google.cloud.talent.v4beta1.Job.description].
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Job.DerivedInfo)
            ),
        ),
        ProcessingOptions=_reflection.GeneratedProtocolMessageType(
            "ProcessingOptions",
            (_message.Message,),
            dict(
                DESCRIPTOR=_JOB_PROCESSINGOPTIONS,
                __module__="google.cloud.talent_v4beta1.proto.job_pb2",
                __doc__="""Options for job processing.
    
    
    Attributes:
        disable_street_address_resolution:
            If set to ``true``, the service does not attempt to resolve a
            more precise address for the job.
        html_sanitization:
            Option for job HTML content sanitization. Applied fields are:
            -  description -  applicationInfo.instruction -  incentives -
            qualifications -  responsibilities  HTML tags in these fields
            may be stripped if sanitiazation isn't disabled.  Defaults to 
            [HtmlSanitization.SIMPLE\_FORMATTING\_ONLY][google.cloud.talen
            t.v4beta1.HtmlSanitization.SIMPLE\_FORMATTING\_ONLY].
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Job.ProcessingOptions)
            ),
        ),
        CustomAttributesEntry=_reflection.GeneratedProtocolMessageType(
            "CustomAttributesEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_JOB_CUSTOMATTRIBUTESENTRY,
                __module__="google.cloud.talent_v4beta1.proto.job_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Job.CustomAttributesEntry)
            ),
        ),
        DESCRIPTOR=_JOB,
        __module__="google.cloud.talent_v4beta1.proto.job_pb2",
        __doc__="""A Job resource represents a job posting (also referred to
  as a "job listing" or "job requisition"). A job belongs to a
  [Company][google.cloud.talent.v4beta1.Company], which is the hiring
  entity responsible for the job.
  
  
  Attributes:
      name:
          Required during job update.  The resource name for the job.
          This is generated by the service when a job is created.  The
          format is
          "projects/{project\_id}/tenants/{tenant\_id}/jobs/{job\_id}".
          For example, "projects/foo/tenants/bar/jobs/baz".  If tenant
          id is unspecified, the default tenant is used. For example,
          "projects/foo/jobs/bar".  Use of this field in job queries and
          API calls is preferred over the use of [requisition\_id][googl
          e.cloud.talent.v4beta1.Job.requisition\_id] since this value
          is unique.
      company:
          Required. The resource name of the company listing the job.
          The format is "projects/{project\_id}/tenants/{tenant\_id}/com
          panies/{company\_id}". For example,
          "projects/foo/tenants/bar/companies/baz".  If tenant id is
          unspecified, the default tenant is used. For example,
          "projects/foo/companies/bar".
      requisition_id:
          Required. The requisition ID, also referred to as the posting
          ID, is assigned by the client to identify a job. This field is
          intended to be used by clients for client identification and
          tracking of postings. A job isn't allowed to be created if
          there is another job with the same
          [company][google.cloud.talent.v4beta1.Job.name], [language\_co
          de][google.cloud.talent.v4beta1.Job.language\_code] and [requi
          sition\_id][google.cloud.talent.v4beta1.Job.requisition\_id].
          The maximum number of allowed characters is 255.
      title:
          Required. The title of the job, such as "Software Engineer"
          The maximum number of allowed characters is 500.
      description:
          Required. The description of the job, which typically includes
          a multi-paragraph description of the company and related
          information. Separate fields are provided on the job object
          for [responsibilities][google.cloud.talent.v4beta1.Job.respons
          ibilities], [qualifications][google.cloud.talent.v4beta1.Job.q
          ualifications], and other job characteristics. Use of these
          separate job fields is recommended.  This field accepts and
          sanitizes HTML input, and also accepts bold, italic, ordered
          list, and unordered list markup tags.  The maximum number of
          allowed characters is 100,000.
      addresses:
          Strongly recommended for the best service experience.
          Location(s) where the employer is looking to hire for this job
          posting.  Specifying the full street address(es) of the hiring
          location enables better API results, especially job searches
          by commute time.  At most 50 locations are allowed for best
          search performance. If a job has more locations, it is
          suggested to split it into multiple jobs with unique [requisit
          ion\_id][google.cloud.talent.v4beta1.Job.requisition\_id]s
          (e.g. 'ReqA' becomes 'ReqA-1', 'ReqA-2', and so on.) as
          multiple jobs with the same
          [company][google.cloud.talent.v4beta1.Job.company], [language\
          _code][google.cloud.talent.v4beta1.Job.language\_code] and [re
          quisition\_id][google.cloud.talent.v4beta1.Job.requisition\_id
          ] are not allowed. If the original [requisition\_id][google.cl
          oud.talent.v4beta1.Job.requisition\_id] must be preserved, a
          custom field should be used for storage. It is also suggested
          to group the locations that close to each other in the same
          job for better search experience.  The maximum number of
          allowed characters is 500.
      application_info:
          Job application information.
      job_benefits:
          The benefits included with the job.
      compensation_info:
          Job compensation information (a.k.a. "pay rate") i.e., the
          compensation that will paid to the employee.
      custom_attributes:
          A map of fields to hold both filterable and non-filterable
          custom job attributes that are not covered by the provided
          structured fields.  The keys of the map are strings up to 64
          bytes and must match the pattern: [a-zA-Z][a-zA-Z0-9\_]\*. For
          example, key0LikeThis or KEY\_1\_LIKE\_THIS.  At most 100
          filterable and at most 100 unfilterable keys are supported.
          For filterable ``string_values``, across all keys at most 200
          values are allowed, with each string no more than 255
          characters. For unfilterable ``string_values``, the maximum
          total size of ``string_values`` across all keys is 50KB.
      degree_types:
          The desired education degrees for the job, such as Bachelors,
          Masters.
      department:
          The department or functional area within the company with the
          open position.  The maximum number of allowed characters is
          255.
      employment_types:
          The employment type(s) of a job, for example, [full
          time][google.cloud.talent.v4beta1.EmploymentType.FULL\_TIME]
          or [part
          time][google.cloud.talent.v4beta1.EmploymentType.PART\_TIME].
      incentives:
          A description of bonus, commission, and other compensation
          incentives associated with the job not including salary or
          pay.  The maximum number of allowed characters is 10,000.
      language_code:
          The language of the posting. This field is distinct from any
          requirements for fluency that are associated with the job.
          Language codes must be in BCP-47 format, such as "en-US" or
          "sr-Latn". For more information, see `Tags for Identifying
          Languages <https://tools.ietf.org/html/bcp47>`__\ {:
          class="external" target="\_blank" }.  If this field is
          unspecified and
          [Job.description][google.cloud.talent.v4beta1.Job.description]
          is present, detected language code based on
          [Job.description][google.cloud.talent.v4beta1.Job.description]
          is assigned, otherwise defaults to 'en\_US'.
      job_level:
          The experience level associated with the job, such as "Entry
          Level".
      promotion_value:
          A promotion value of the job, as determined by the client. The
          value determines the sort order of the jobs returned when
          searching for jobs using the featured jobs search call, with
          higher promotional values being returned first and ties being
          resolved by relevance sort. Only the jobs with a
          promotionValue >0 are returned in a FEATURED\_JOB\_SEARCH.
          Default value is 0, and negative values are treated as 0.
      qualifications:
          A description of the qualifications required to perform the
          job. The use of this field is recommended as an alternative to
          using the more general
          [description][google.cloud.talent.v4beta1.Job.description]
          field.  This field accepts and sanitizes HTML input, and also
          accepts bold, italic, ordered list, and unordered list markup
          tags.  The maximum number of allowed characters is 10,000.
      responsibilities:
          A description of job responsibilities. The use of this field
          is recommended as an alternative to using the more general
          [description][google.cloud.talent.v4beta1.Job.description]
          field.  This field accepts and sanitizes HTML input, and also
          accepts bold, italic, ordered list, and unordered list markup
          tags.  The maximum number of allowed characters is 10,000.
      posting_region:
          The job
          [PostingRegion][google.cloud.talent.v4beta1.PostingRegion]
          (for example, state, country) throughout which the job is
          available. If this field is set, a
          [LocationFilter][google.cloud.talent.v4beta1.LocationFilter]
          in a search query within the job region finds this job posting
          if an exact location match isn't specified. If this field is
          set to [PostingRegion.NATION][google.cloud.talent.v4beta1.Post
          ingRegion.NATION] or [PostingRegion.ADMINISTRATIVE\_AREA][goog
          le.cloud.talent.v4beta1.PostingRegion.ADMINISTRATIVE\_AREA],
          setting job
          [Job.addresses][google.cloud.talent.v4beta1.Job.addresses] to
          the same location level as this field is strongly recommended.
      visibility:
          Deprecated. The job is only visible to the owner.  The
          visibility of the job.  Defaults to [Visibility.ACCOUNT\_ONLY]
          [google.cloud.talent.v4beta1.Visibility.ACCOUNT\_ONLY] if not
          specified.
      job_start_time:
          The start timestamp of the job in UTC time zone. Typically
          this field is used for contracting engagements. Invalid
          timestamps are ignored.
      job_end_time:
          The end timestamp of the job. Typically this field is used for
          contracting engagements. Invalid timestamps are ignored.
      posting_publish_time:
          The timestamp this job posting was most recently published.
          The default value is the time the request arrives at the
          server. Invalid timestamps are ignored.
      posting_expire_time:
          Strongly recommended for the best service experience.  The
          expiration timestamp of the job. After this timestamp, the job
          is marked as expired, and it no longer appears in search
          results. The expired job can't be listed by the
          [ListJobs][google.cloud.talent.v4beta1.JobService.ListJobs]
          API, but it can be retrieved with the
          [GetJob][google.cloud.talent.v4beta1.JobService.GetJob] API or
          updated with the
          [UpdateJob][google.cloud.talent.v4beta1.JobService.UpdateJob]
          API or deleted with the
          [DeleteJob][google.cloud.talent.v4beta1.JobService.DeleteJob]
          API. An expired job can be updated and opened again by using a
          future expiration timestamp. Updating an expired job fails if
          there is another existing open job with same
          [company][google.cloud.talent.v4beta1.Job.company], [language\
          _code][google.cloud.talent.v4beta1.Job.language\_code] and [re
          quisition\_id][google.cloud.talent.v4beta1.Job.requisition\_id
          ].  The expired jobs are retained in our system for 90 days.
          However, the overall expired job count cannot exceed 3 times
          the maximum number of open jobs over previous 7 days. If this
          threshold is exceeded, expired jobs are cleaned out in order
          of earliest expire time. Expired jobs are no longer accessible
          after they are cleaned out.  Invalid timestamps are ignored,
          and treated as expire time not provided.  If the timestamp is
          before the instant request is made, the job is treated as
          expired immediately on creation. This kind of job can not be
          updated. And when creating a job with past timestamp, the [pos
          ting\_publish\_time][google.cloud.talent.v4beta1.Job.posting\_
          publish\_time] must be set before [posting\_expire\_time][goog
          le.cloud.talent.v4beta1.Job.posting\_expire\_time]. The
          purpose of this feature is to allow other objects, such as
          [Application][google.cloud.talent.v4beta1.Application], to
          refer a job that didn't exist in the system prior to becoming
          expired. If you want to modify a job that was expired on
          creation, delete it and create a new one.  If this value isn't
          provided at the time of job creation or is invalid, the job
          posting expires after 30 days from the job's creation time.
          For example, if the job was created on 2017/01/01 13:00AM UTC
          with an unspecified expiration date, the job expires after
          2017/01/31 13:00AM UTC.  If this value isn't provided on job
          update, it depends on the field masks set by [UpdateJobRequest
          .update\_mask][google.cloud.talent.v4beta1.UpdateJobRequest.up
          date\_mask]. If the field masks include [job\_end\_time][googl
          e.cloud.talent.v4beta1.Job.job\_end\_time], or the masks are
          empty meaning that every field is updated, the job posting
          expires after 30 days from the job's last update time.
          Otherwise the expiration date isn't updated.
      posting_create_time:
          Output only. The timestamp when this job posting was created.
      posting_update_time:
          Output only. The timestamp when this job posting was last
          updated.
      company_display_name:
          Output only. Display name of the company listing the job.
      derived_info:
          Output only. Derived details about the job posting.
      processing_options:
          Options for job processing.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Job)
    ),
)
_sym_db.RegisterMessage(Job)
_sym_db.RegisterMessage(Job.ApplicationInfo)
_sym_db.RegisterMessage(Job.DerivedInfo)
_sym_db.RegisterMessage(Job.ProcessingOptions)
_sym_db.RegisterMessage(Job.CustomAttributesEntry)


DESCRIPTOR._options = None
_JOB_CUSTOMATTRIBUTESENTRY._options = None
_JOB.fields_by_name["company"]._options = None
_JOB.fields_by_name["requisition_id"]._options = None
_JOB.fields_by_name["title"]._options = None
_JOB.fields_by_name["description"]._options = None
_JOB.fields_by_name["visibility"]._options = None
_JOB.fields_by_name["posting_create_time"]._options = None
_JOB.fields_by_name["posting_update_time"]._options = None
_JOB.fields_by_name["company_display_name"]._options = None
_JOB.fields_by_name["derived_info"]._options = None
_JOB._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from __future__ import absolute_import

from google.cloud.talent_v4beta1 import ApplicationServiceClient
from google.cloud.talent_v4beta1 import CompanyServiceClient
from google.cloud.talent_v4beta1 import CompletionClient
from google.cloud.talent_v4beta1 import EventServiceClient
from google.cloud.talent_v4beta1 import JobServiceClient
from google.cloud.talent_v4beta1 import ProfileServiceClient
from google.cloud.talent_v4beta1 import TenantServiceClient
from google.cloud.talent_v4beta1 import enums
from google.cloud.talent_v4beta1 import types


__all__ = (
    "enums",
    "types",
    "ApplicationServiceClient",
    "CompanyServiceClient",
    "CompletionClient",
    "EventServiceClient",
    "JobServiceClient",
    "ProfileServiceClient",
    "TenantServiceClient",
)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit tests."""

import mock
import pytest

from google.cloud import talent_v4beta1
from google.cloud.talent_v4beta1.proto import event_pb2
from google.cloud.talent_v4beta1.proto import event_service_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestEventServiceClient(object):
    def test_create_client_event(self):
        # Setup Expected Response
        request_id = "requestId37109963"
        event_id = "eventId278118624"
        event_notes = "eventNotes445073628"
        expected_response = {
            "request_id": request_id,
            "event_id": event_id,
            "event_notes": event_notes,
        }
        expected_response = event_pb2.ClientEvent(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.EventServiceClient()

        # Setup Request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        client_event = {}

        response = client.create_client_event(parent, client_event)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = event_service_pb2.CreateClientEventRequest(
            parent=parent, client_event=client_event
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_client_event_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.EventServiceClient()

        # Setup request
        parent = client.tenant_path("[PROJECT]", "[TENANT]")
        client_event = {}

        with pytest.raises(CustomException):
            client.create_client_event(parent, client_event)
